@@ -3,7 +3,7 @@ use warnings;
 use 5.006;
 
 package Task::Date::Holidays;
-$Task::Date::Holidays::VERSION = '0.04';
+$Task::Date::Holidays::VERSION = '0.05';
 1;
 
 __END__
@@ -16,7 +16,7 @@ Task::Date::Holidays - Work package for holiday modules in the Date::Holidays na
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -136,20 +136,22 @@ or by sending mail to
 
 Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 
-=head1 ACKNOWLEDGEMENT
+=head1 ACKNOWLEDGEMENTS
 
 =over
 
-=item * Alexander Nalobin, patch for inclusion of Date::Holidays::RU, 0.04
+=item * Alexander Nalobin (NALOBIN), patch for inclusion of Date::Holidays::RU, 0.04
 
-=item * Gabor Szabo, patch assisting META data generation, 0.03
+=item * Gabor Szabo (SZABGAB), patch assisting META data generation, 0.03
+
+=item * Alberto Simoes (AMBS), for patching Date::Holidays::PT which was broken
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
 Task-Date-Holidays and related modules are (C) by Jonas B. Nielsen, (jonasbn)
-2014
+2014-2015
 
 Task-Date-Holidays and related modules are released under the Artistic License 2.0
 
